@@ -208,4 +208,4 @@ def main():
         LOG.error(e)
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
