@@ -16,13 +16,10 @@
 import pecan
 import pecan.deploy
 from oslo_config import cfg
-from oslo_log import log as logging
 
 from designate.api.v2 import patches
 
 
-LOG = logging.getLogger(__name__)
-
 cfg.CONF.register_opts([
     cfg.BoolOpt('pecan_debug', default=False,
                 help='Pecan HTML Debug Interface'),
