@@ -29,18 +29,13 @@ import inspect
 import pecan
 import pecan.rest
 import pecan.routing
-from oslo_log import log as logging
 
 from designate import exceptions
 from designate.central import rpcapi as central_rpcapi
 from designate.pool_manager import rpcapi as pool_mgr_rpcapi
-from designate.zone_manager import rpcapi as zone_manager_rpcapi
 from designate.i18n import _
 
 
-LOG = logging.getLogger(__name__)
-
-
 class RestController(pecan.rest.RestController):
     """
     Extension for Pecan's RestController to better handle POST/PUT/PATCH
@@ -60,12 +55,8 @@ class RestController(pecan.rest.RestController):
     def pool_mgr_api(self):
         return pool_mgr_rpcapi.PoolManagerAPI.get_instance()
 
-    @property
-    def zone_manager_api(self):
-        return zone_manager_rpcapi.ZoneManagerAPI.get_instance()
-
     def _apply_filter_params(self, params, accepted_filters, criterion):
-        invalid=[]
+        invalid = []
         for k in params:
             if k in accepted_filters:
                 criterion[k] = params[k].replace("*", "%")
