@@ -21,6 +21,9 @@ from designate import exceptions
 from designate.api.v2.controllers import rest
 from designate.objects import ZoneTransferRequest
 from designate.objects.adapters import DesignateAdapter
+from designate.i18n import _LI
+
+
 LOG = logging.getLogger(__name__)
 
 
@@ -29,17 +32,22 @@ class TransferRequestsController(rest.RestController):
     SORT_KEYS = ['created_at', 'id', 'updated_at']
 
     @pecan.expose(template='json:', content_type='application/json')
-    @utils.validate_uuid('transfer_request_id')
-    def get_one(self, transfer_request_id):
+    @utils.validate_uuid('zone_transfer_request_id')
+    def get_one(self, zone_transfer_request_id):
         """Get transfer_request"""
 
         request = pecan.request
         context = request.environ['context']
 
+        transfer_request = self.central_api.get_zone_transfer_request(
+            context, zone_transfer_request_id)
+
+        LOG.info(_LI("Retrieved %(transfer_request)s"),
+                 {'transfer_request': transfer_request})
+
         return DesignateAdapter.render(
             'API_v2',
-            self.central_api.get_zone_transfer_request(
-                context, transfer_request_id),
+            transfer_request,
             request=request,
             context=context)
 
@@ -51,15 +59,20 @@ class TransferRequestsController(rest.RestController):
 
         # Extract the pagination params
         marker, limit, sort_key, sort_dir = utils.get_paging_params(
-            params, self.SORT_KEYS)
+                context, params, self.SORT_KEYS)
 
         # Extract any filter params.
         criterion = self._apply_filter_params(params, ('status',), {})
 
+        zone_transfer_requests = self.central_api.find_zone_transfer_requests(
+            context, criterion, marker, limit, sort_key, sort_dir)
+
+        LOG.info(_LI("Retrieved %(zone_transfer_requests)s"),
+                 {'zone_transfer_requests': zone_transfer_requests})
+
         return DesignateAdapter.render(
             'API_v2',
-            self.central_api.find_zone_transfer_requests(
-                context, criterion, marker, limit, sort_key, sort_dir),
+            zone_transfer_requests,
             request=request,
             context=context)
 
@@ -89,6 +102,9 @@ class TransferRequestsController(rest.RestController):
             context, zone_transfer_request)
         response.status_int = 201
 
+        LOG.info(_LI("Created %(zone_transfer_request)s"),
+                 {'zone_transfer_request': zone_transfer_request})
+
         zone_transfer_request = DesignateAdapter.render(
             'API_v2', zone_transfer_request, request=request, context=context)
 
@@ -121,6 +137,9 @@ class TransferRequestsController(rest.RestController):
         zone_transfer_request = self.central_api.update_zone_transfer_request(
             context, zone_transfer_request)
 
+        LOG.info(_LI("Updated %(zt_request)s"),
+                 {'zt_request': zone_transfer_request})
+
         response.status_int = 200
 
         return DesignateAdapter.render(
@@ -134,10 +153,13 @@ class TransferRequestsController(rest.RestController):
         response = pecan.response
         context = request.environ['context']
 
-        self.central_api.delete_zone_transfer_request(
+        zone_transfer_request = self.central_api.delete_zone_transfer_request(
             context, zone_transfer_request_id)
 
         response.status_int = 204
 
+        LOG.info(_LI("Deleted %(zone_transfer_request)s"),
+                 {'zone_transfer_request': zone_transfer_request})
+
         # NOTE: This is a hack and a half.. But Pecan needs it.
         return ''
