@@ -31,6 +31,22 @@ from designate.i18n import _LI
 LOG = logging.getLogger(__name__)
 CFG_GROUP = 'backend:agent:denominator'
 
+"""GROUP = backend:agent:denominator"""
+denominator_group = cfg.OptGroup(
+            name='backend:agent:denominator',
+            title='Backend options for Denominator',
+        )
+
+denominator_opts = [
+    cfg.StrOpt('name', default='fake',
+               help='Name of the affected provider'),
+    cfg.StrOpt('config_file', default='/etc/denominator.conf',
+               help='Path to Denominator configuration file')
+]
+
+cfg.CONF.register_group(denominator_group)
+cfg.CONF.register_opts(denominator_opts, group=denominator_group)
+
 
 class Denominator(object):
 
@@ -98,19 +114,7 @@ class DenominatorBackend(base.AgentBackend):
 
     @classmethod
     def get_cfg_opts(cls):
-        group = cfg.OptGroup(
-            name=CFG_GROUP,
-            title='Backend options for Denominator',
-        )
-
-        opts = [
-            cfg.StrOpt('name', default='fake',
-                help='Name of the affected provider'),
-            cfg.StrOpt('config_file', default='/etc/denominator.conf',
-                help='Path to Denominator configuration file')
-        ]
-
-        return [(group, opts)]
+        return [(denominator_group, denominator_opts)]
 
     def start(self):
         LOG.info(_LI("Started Denominator backend"))
@@ -137,7 +141,7 @@ class DenominatorBackend(base.AgentBackend):
 
     def create_zone(self, zone):
         LOG.debug("Creating %s" % zone.origin.to_text())
-        zone_name = zone.origin.to_text(omit_final_dot=True)
+        zone_name = zone.origin.to_text(omit_final_dot=True).decode('utf-8')
 
         # Use SOA TTL as zone default TTL
         soa_record = zone.find_rrset(zone.origin, dns.rdatatype.SOA)
@@ -155,7 +159,7 @@ class DenominatorBackend(base.AgentBackend):
 
             # Add records one by one.
             for name, ttl, rtype, data in self._iterate_records(zone):
-                # Some providers do not support creationg of SOA record.
+                # Some providers do not support creation of SOA record.
                 rdatatype = dns.rdatatype.from_text(rtype)
                 if rdatatype == dns.rdatatype.SOA:
                     continue
@@ -169,7 +173,7 @@ class DenominatorBackend(base.AgentBackend):
 
     def update_zone(self, zone):
         LOG.debug("Updating %s" % zone.origin)
-        zone_name = zone.origin.to_text(omit_final_dot=True)
+        zone_name = zone.origin.to_text(omit_final_dot=True).decode('utf-8')
 
         soa_record = zone.find_rrset(zone.origin, dns.rdatatype.SOA)
         rname = soa_record.items[0].rname.derelativize(origin=zone.origin)
@@ -237,7 +241,7 @@ class DenominatorBackend(base.AgentBackend):
     def _iterate_records(self, zone):
         for rname, ttl, rdata in zone.iterate_rdatas():
             name = rname.derelativize(origin=zone.origin)
-            name = name.to_text(omit_final_dot=True)
+            name = name.to_text(omit_final_dot=True).decode('utf-8')
 
             data = rdata.to_text(origin=zone.origin, relativize=False)
             yield name, ttl, dns.rdatatype.to_text(rdata.rdtype), data
