@@ -33,14 +33,16 @@ class DesignateContext(context.RequestContext):
     original_tenant = None
     _edit_managed_records = False
     _client_addr = None
+    FROM_DICT_EXTRA_KEYS = [
+        'original_tenant', 'service_catalog', 'all_tenants', 'abandon',
+        'edit_managed_records', 'tsigkey_id', 'hide_counts', 'client_addr',
+    ]
 
     def __init__(self, service_catalog=None, all_tenants=False, abandon=None,
-                 tsigkey_id=None, user_identity=None, original_tenant=None,
+                 tsigkey_id=None, original_tenant=None,
                  edit_managed_records=False, hide_counts=False,
                  client_addr=None, **kwargs):
 
-        # NOTE: user_identity may be passed in, but will be silently dropped as
-        #       it is a generated field based on several others.
         super(DesignateContext, self).__init__(**kwargs)
 
         self.service_catalog = service_catalog
@@ -92,10 +94,6 @@ class DesignateContext(context.RequestContext):
 
         return copy.deepcopy(d)
 
-    @classmethod
-    def from_dict(cls, values):
-        return cls(**values)
-
     def elevated(self, show_deleted=None, all_tenants=False,
                  edit_managed_records=False):
         """Return a version of this context with admin flag set.
