@@ -247,6 +247,10 @@ class Duplicate(Base):
     error_type = 'duplicate'
 
 
+class DuplicateServiceStatus(Duplicate):
+    error_type = 'duplicate_service_status'
+
+
 class DuplicateQuota(Duplicate):
     error_type = 'duplicate_quota'
 
@@ -351,6 +355,10 @@ class NotFound(Base):
     error_type = 'not_found'
 
 
+class ServiceStatusNotFound(NotFound):
+    error_type = 'service_status_not_found'
+
+
 class QuotaNotFound(NotFound):
     error_type = 'quota_not_found'
 
