@@ -113,7 +113,7 @@ class RequestHandler(xfr.XFRMixin):
             question = request.question[0]
 
         criterion = {
-            'name': question.name.to_text(),
+            'name': question.name.to_text().decode('utf-8'),
             'type': 'SECONDARY',
             'deleted': False
         }
@@ -229,7 +229,7 @@ class RequestHandler(xfr.XFRMixin):
         # validate the parameters
         try:
             criterion = self._zone_criterion_from_request(
-                request, {'name': q_rrset.name.to_text()})
+                request, {'name': q_rrset.name.to_text().decode('utf-8')})
             zone = self.storage.find_zone(context, criterion)
 
         except exceptions.ZoneNotFound:
@@ -349,7 +349,7 @@ class RequestHandler(xfr.XFRMixin):
             # TODO(vinod) once validation is separated from the api,
             # validate the parameters
             criterion = {
-                'name': q_rrset.name.to_text(),
+                'name': q_rrset.name.to_text().decode('utf-8'),
                 'type': dns.rdatatype.to_text(q_rrset.rdtype),
                 'zones_deleted': False
             }
