@@ -31,6 +31,10 @@ CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
+neutron_group = cfg.OptGroup(
+            name='network_api:neutron', title="Configuration network api"
+        )
+
 neutron_opts = [
     cfg.ListOpt('endpoints',
                 help='URL to use if None in the ServiceCatalog that is '
@@ -61,7 +65,8 @@ neutron_opts = [
                     'neutron client requests.'),
 ]
 
-cfg.CONF.register_opts(neutron_opts, group='network_api:neutron')
+cfg.CONF.register_group(neutron_group)
+cfg.CONF.register_opts(neutron_opts, group=neutron_group)
 
 
 def get_client(context, endpoint):
@@ -117,7 +122,7 @@ class NeutronNetworkAPI(base.NetworkAPI):
                 # activated in a particular region, we'll just log the failure
                 # and go on with our lives.
                 LOG.warning(_LW("Calling Neutron resulted in a 401, "
-                             "please investigate."))
+                                "please investigate."))
                 LOG.exception(e)
                 return
             except Exception as e:
@@ -145,7 +150,7 @@ class NeutronNetworkAPI(base.NetworkAPI):
 
         # NOTE: Sadly tg code doesn't give us a good way to handle failures.
         if failed:
-            msg = 'Failed retrieving FLoatingIPs from Neutron in %s' % \
+            msg = 'Failed retrieving FloatingIPs from Neutron in %s' % \
                 ", ".join(['%s - %s' % (i[1], i[2]) for i in failed])
             raise exceptions.NeutronCommunicationFailure(msg)
         return data
