@@ -12,14 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 from six.moves.urllib import parse
-from oslo_log import log as logging
 from oslo_config import cfg
 
 from designate.objects.adapters import base
 from designate.objects import base as obj_base
 from designate import exceptions
 
-LOG = logging.getLogger(__name__)
 
 cfg.CONF.import_opt('api_base_uri', 'designate.api', group='service:api')
 cfg.CONF.import_opt('enable_host_header', 'designate.api', group='service:api')
@@ -78,7 +76,7 @@ class APIv2Adapter(base.DesignateAdapter):
     #####################
 
     @classmethod
-    def _get_resource_links(cls, object, request):
+    def _get_resource_links(cls, obj, request):
         if cfg.CONF['service:api'].enable_host_header:
             try:
                 base_uri = request.host_url
@@ -87,11 +85,11 @@ class APIv2Adapter(base.DesignateAdapter):
         else:
             base_uri = cls.BASE_URI
 
-        return {'self': '%s%s/%s' %
-                (base_uri, cls._get_path(request), object.id)}
+        path = cls._get_path(request, obj)
+        return {'self': '%s%s/%s' % (base_uri, path, obj.id)}
 
     @classmethod
-    def _get_path(cls, request):
+    def _get_path(cls, request, *args):
         path = request.path.lstrip('/').split('/')
         item_path = ''
         for part in path:
