@@ -37,6 +37,10 @@ from designate.tests import fixtures
 from designate.tests import resources
 from designate.manage import database as manage_database
 
+import eventlet
+
+eventlet.monkey_patch(os=False)
+
 
 LOG = logging.getLogger(__name__)
 
@@ -51,6 +55,10 @@ cfg.CONF.import_opt('cache_driver', 'designate.pool_manager',
 cfg.CONF.import_opt('connection',
                     'designate.pool_manager.cache.impl_sqlalchemy',
                     group='pool_manager_cache:sqlalchemy')
+cfg.CONF.import_opt('emitter_type', 'designate.service_status',
+                    group="heartbeat_emitter")
+cfg.CONF.import_opt('scheduler_filters', 'designate.scheduler',
+                    group="service:central")
 default_pool_id = cfg.CONF['service:central'].default_pool_id
 
 _TRUE_VALUES = ('true', '1', 'yes', 'y')
@@ -62,6 +70,14 @@ class TestTimeoutError(Exception):
 
 
 class TestCase(base.BaseTestCase):
+    service_status_fixtures = [{
+        'service_name': 'foo',
+        'hostname': 'bar',
+        'status': "UP",
+        'stats': {},
+        'capabilities': {},
+    }]
+
     quota_fixtures = [{
         'resource': 'zones',
         'hard_limit': 5,
@@ -284,6 +300,23 @@ class TestCase(base.BaseTestCase):
         'task_type': 'IMPORT'
     }]
 
+    zone_export_fixtures = [{
+        'status': 'PENDING',
+        'zone_id': None,
+        'message': None,
+        'task_type': 'EXPORT'
+    }, {
+        'status': 'ERROR',
+        'zone_id': None,
+        'message': None,
+        'task_type': 'EXPORT'
+    }, {
+        'status': 'COMPLETE',
+        'zone_id': '6ca6baef-3305-4ad0-a52b-a82df5752b62',
+        'message': None,
+        'task_type': 'EXPORT'
+    }]
+
     def setUp(self):
         super(TestCase, self).setUp()
 
@@ -294,7 +327,7 @@ class TestCase(base.BaseTestCase):
         self.messaging_conf.response_timeout = 5
         self.useFixture(self.messaging_conf)
 
-        self.config(notification_driver='test')
+        self.config(notification_driver=['test'])
 
         self.useFixture(fixtures.RPCFixture(cfg.CONF))
 
@@ -303,6 +336,11 @@ class TestCase(base.BaseTestCase):
             group='service:central'
         )
 
+        self.config(
+            emitter_type="noop",
+            group="heartbeat_emitter"
+        )
+
         self.config(
             auth_strategy='noauth',
             group='service:api'
@@ -384,11 +422,11 @@ class TestCase(base.BaseTestCase):
 
         # Fill out the necessary pool details
         pool.ns_records = objects.PoolNsRecordList.from_list([
-            {'hostname': 'ns1.example.org.', 'priority': 0}
+            {'hostname': 'ns1.example.org.', 'priority': 1}
         ])
 
         pool.targets = objects.PoolTargetList.from_list([
-            {'type': 'fake', u'description': "Fake PoolTarget for Tests"}
+            {'type': 'fake', u'description': u"Fake PoolTarget for Tests"}
         ])
 
         # Save the default pool
@@ -580,6 +618,30 @@ class TestCase(base.BaseTestCase):
         _values.update(values)
         return _values
 
+    def get_zone_export_fixture(self, fixture=0, values=None):
+        values = values or {}
+
+        _values = copy.copy(self.zone_export_fixtures[fixture])
+        _values.update(values)
+        return _values
+
+    def get_service_status_fixture(self, fixture=0, values=None):
+        values = values or {}
+
+        _values = copy.copy(self.service_status_fixtures[fixture])
+        _values.update(values)
+        return _values
+
+    def update_service_status(self, **kwargs):
+        context = kwargs.pop('context', self.admin_context)
+        fixture = kwargs.pop('fixture', 0)
+
+        values = self.get_service_status_fixture(
+            fixture=fixture, values=kwargs)
+
+        return self.central_service.update_service_status(
+            context, objects.ServiceStatus.from_dict(values))
+
     def create_tld(self, **kwargs):
         context = kwargs.pop('context', self.admin_context)
         fixture = kwargs.pop('fixture', 0)
@@ -733,6 +795,16 @@ class TestCase(base.BaseTestCase):
         return self.storage.create_zone_import(
             context, objects.ZoneImport.from_dict(zone_import))
 
+    def create_zone_export(self, **kwargs):
+        context = kwargs.pop('context', self.admin_context)
+        fixture = kwargs.pop('fixture', 0)
+
+        zone_export = self.get_zone_export_fixture(fixture=fixture,
+                                               values=kwargs)
+
+        return self.storage.create_zone_export(
+            context, objects.ZoneExport.from_dict(zone_export))
+
     def wait_for_import(self, zone_import_id, errorok=False):
         """
            Zone imports spawn a thread to parse the zone file and
