@@ -18,7 +18,6 @@ import json
 import functools
 import inspect
 import os
-import uuid
 import socket
 
 import six
@@ -28,6 +27,7 @@ from oslo_config import cfg
 from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 from oslo_utils.netutils import is_valid_ipv6
 
 from designate.common import config
@@ -39,17 +39,18 @@ from designate.i18n import _LI
 LOG = logging.getLogger(__name__)
 
 
-cfg.CONF.register_opts([
+helper_opts = [
     cfg.StrOpt('root-helper',
-               default='sudo designate-rootwrap /etc/designate/rootwrap.conf')
-])
+               default='sudo designate-rootwrap /etc/designate/rootwrap.conf',
+               help='designate-rootwrap configuration')
+]
 
 
 # Set some proxy options (Used for clients that need to communicate via a
 # proxy)
-cfg.CONF.register_group(cfg.OptGroup(
+proxy_group = cfg.OptGroup(
     name='proxy', title="Configuration for Client Proxy"
-))
+)
 
 proxy_opts = [
     cfg.StrOpt('http_proxy',
@@ -60,7 +61,10 @@ proxy_opts = [
                 help='These addresses should not be proxied')
 ]
 
-cfg.CONF.register_opts(proxy_opts, group='proxy')
+
+cfg.CONF.register_opts(helper_opts)
+cfg.CONF.register_group(proxy_group)
+cfg.CONF.register_opts(proxy_opts, proxy_group)
 
 # Default TCP/UDP ports
 
@@ -302,7 +306,7 @@ def deep_dict_merge(a, b):
 
 
 def generate_uuid():
-    return str(uuid.uuid4())
+    return uuidutils.generate_uuid(dashed=True)
 
 
 def is_uuid_like(val):
@@ -312,10 +316,7 @@ def is_uuid_like(val):
     aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa
 
     """
-    try:
-        return str(uuid.UUID(val)) == val
-    except (TypeError, ValueError, AttributeError):
-        return False
+    return uuidutils.is_uuid_like(val)
 
 
 def validate_uuid(*check):
